@@ -1,4 +1,4 @@
-use swc_common::chain;
+use swc_common::{chain, SyntaxContext};
 use swc_ecma_visit::VisitMut;
 
 use super::compute_char_freq::CharFreqInfo;
@@ -13,9 +13,10 @@ pub(crate) fn name_mangler(
     options: MangleOptions,
     char_freq_info: CharFreqInfo,
     marks: Marks,
+    top_level_ctxt: SyntaxContext,
 ) -> impl VisitMut {
     chain!(
         self::private_name::private_name_mangler(options.keep_private_props),
-        self::real_impl::name_mangler(options, char_freq_info, marks)
+        self::real_impl::name_mangler(options, char_freq_info, marks, top_level_ctxt)
     )
 }
